<?php
/*
 Plugin Name:QR Code Widget
 Plugin URI: http://www.poluschin.info
 Description: QR Code generator for your blog with Widget support
 Version: 1.0.1
 Author: Wjatscheslaw Poluschin <wjatscheslaw@poluschin.info>
 Author URI: http://www.poluschin.info
 */

$qr_code_plugin_dir =  dirname(__FILE__).'/';
$qr_code_plugin_cache_dir = dirname(__FILE__).'/cache/';

/**
 * qr_code
 *
 * generate qr code
 * based on QRcode image PHP Scripts from Y.Swetake
 * @access  public
 * @param   string  $data data
 * @param   string  $ecc  ECC level (L or M or Q or H)
 * @param   string  $type J:jpeg image , other: PNG image
 * @param   integer $size dafault PNG:4 JPEG:8
 * @param   integer $version 1-40 or Auto select if you do not set
 * @return  string
 */
function qr_code($data, $ecc = 'M', $type = 'J', $size = '2', $version = null)
{

	global $qr_code_plugin_cache_dir, $qr_code_plugin_dir;
	$params = array('d' => $data,
                'e' => $ecc,
                't' => $type,
                's' => $size,
                'v' => $version,
	);
	$cache_id   = md5(serialize($params));
	$cache_file = $cache_id.($type=='J'?'.jpeg':'.png');
	if ( is_writable($qr_code_plugin_cache_dir) && !is_readable($qr_code_plugin_cache_dir.$cache_file) ) {
		$qrcode_data_string   = urlencode($data);
		$qrcode_error_correct = $ecc;
		$qrcode_module_size   = $size;
		$qrcode_version       = $version;
		$qrcode_image_type    = $type;

		ob_start();
		require_once ($qr_code_plugin_dir.'php/qr_img.php');
		$out = ob_get_contents();
		ob_end_clean();

		$cache = fopen($qr_code_plugin_cache_dir.$cache_file, 'w+');
		fwrite($cache, $out);
		fclose($cache);
	} elseif (!is_writable($qr_code_plugin_cache_dir)) {
		return "";
	}
	return get_option('siteurl').'/wp-content/plugins/qr-code-widget/cache/'.$cache_file;
}

// widget
function qr_code_widget_install(){
	$qr_code_plugin_cache_dir = dirname(__FILE__).'/cache/';
	$newoptions = get_option('qr_code_widget');
	$newoptions['format']='J';
	$newoptions['size']='2';
	add_option('qr_code_widget', $newoptions);
	error_log($qr_code_plugin_cache_dir, 0);
	if (! is_dir($qr_code_plugin_cache_dir)){
		mkdir($qr_code_plugin_cache_dir);
	}
}
function qr_code_widget_uninstall(){
	delete_option('qr_code_widget');
}

function init_qr_code_widget(){
	if (!function_exists('register_sidebar_widget'))
	return;

	function qr_code_widget($args){
		extract($args);
		$options = get_option('qr_code_widget');

		$title = empty($options['title']) ? __('QR Barcode') : $options['title'];
		$format = empty($options['format']) ? __('J') : $options['format'];
		$size = empty($options['size']) ? __('2') : $options['size'];
		echo $before_widget;
		echo $before_title . $title . $after_title;
		if( !stristr( $_SERVER['PHP_SELF'], 'widgets.php' ) ){
			if (function_exists('qr_code')){
				if (is_home())$url=get_settings('home');
				elseif (is_category())$url=$_SERVER["HTTP_HOST"] . $_SERVER["REQUEST_URI"];
				else $url=get_permalink();
				echo '<img src="'. qr_code($url,"M",$format,$size) .'" alt="QR Code for '.the_title('','',false).'"/> ';
			}
		}
		echo $after_widget;
	}

	function  qr_code_widget_control() {
		$options = $newoptions = get_option('qr_code_widget');
		if ( $_POST["qr_code_widget_submit"] ) {
			$newoptions['title'] = strip_tags(stripslashes($_POST["qr_code_widget_title"]));
			$newoptions['format'] = strip_tags(stripslashes($_POST["qr_code_widget_format"]));
			$newoptions['size'] = strip_tags(stripslashes($_POST["qr_code_widget_size"]));
		}
		if ( $options != $newoptions ) {
			$options = $newoptions;
			update_option('qr_code_widget', $options);
		}
		$title = attribute_escape($options['title']);
		$format = attribute_escape($options['format']);
		$size = attribute_escape($options['size']);
		?>
<p><label for="qr_code_widget_title"><?php _e('Title:'); ?> <input class="widefat" id="qr_code_widget_title" name="qr_code_widget_title" type="text" value="<?php echo $title; ?>" /></label></p>
<p>Image Format: <input class="radio" id="qr_code_widget_format" name="qr_code_widget_format" type="radio" value="J" <?php if( $format == "J" ){ echo ' checked="checked"'; } ?>>Jpeg <input
	class="radio" id="qr_code_widget_format" name="qr_code_widget_format"
	type="radio" value="P"
	<?php if( $format == "P" ){ echo ' checked="checked"'; } ?>>Png<br />

</p>
<p><label for="qr_code_widget_size"><?php _e('Size:'); ?> <input
	class="widefat" id="qr_code_widget_size" name="qr_code_widget_size"
	type="text" value="<?php echo $size; ?>" /></label></p>
<input
	type="hidden" id="qr_code_widget_submit" name="qr_code_widget_submit"
	value="1" />
	<?
	}

	register_sidebar_widget( "QR Barcode", qr_code_widget );
	register_widget_control( "QR Barcode", "qr_code_widget_control" );
}

add_action('widgets_init', 'init_qr_code_widget');
register_activation_hook( __FILE__, 'qr_code_widget_install' );
register_deactivation_hook( __FILE__, 'qr_code_widget_uninstall' );

